@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import sys
 import os
 #import random
@@ -25,7 +27,7 @@ _ = i18n.language.gettext
 def LoadConfig():
     #get configuration
     global config
-    if(data.debug==1): print "Configuration file:",  data.configFolder+data.ConfigFile
+    if(data.debug==True): print "Configuration file:",  data.configFolder+data.ConfigFile
     config = ConfigParser.SafeConfigParser()
     try:
         config.read(data.configFolder+data.ConfigFile)
@@ -175,13 +177,14 @@ def WriteConfig():
         config.set('main', 'ConfigFileVersion', str(data.configFileVersion))
 
         f=data.configFolder+data.ConfigFile
-        if(data.debug==1): print "Save configuration ("+f+")"
+        if(data.debug==True): print "Save configuration ("+f+")"
         if (not os.path.exists(data.configFolder)):
             print "Create configuration folder: ",  data.configFolder
             os.mkdir(data.configFolder)
         try:
             data.configfile = open(f, 'w')
             config.write(data.configfile)
+            data.configfile.close()
             print "Configuration saved"
         except:
             print "Failed to write configuration file!"
@@ -317,7 +320,7 @@ def SwitchModes(start):
 ## Function to measure used time in a function
 ############################################################################
 #def Show_passed_time(text="",  reset=0):
-#    if(data.debug==0): return
+#    if(data.debug==False): return
 #    now=time.time()
 #    if(reset==1): data.passed_time=now
 #
